---
---

const loadEvent = () => {
  try {
    if (Turbolinks) return 'turbolinks:load'
  } catch {
    return 'DOMContentLoaded'
  }
}

// Inicia y gestiona el stream
const streaming = (element) => {
  // Cambiar el src para que incluya un timestamp, esto engaña a Firefox
  // a recargar el video cuando se corta en lugar de pensar que terminó
  // la descarga y empezar a reproducir desde el principio.
  element.querySelectorAll('source').forEach(source => {
    // Obtener la URL completa hasta el ?
    source.src = source.src.split('?')[0]+'?'+Date.now().toString()
  })

  // Empezar la reproducción
  element.load()
  element.play()
}

document.addEventListener(loadEvent(), () => {
  const transmission = document.querySelector('#transmission')

  if ('mediaSession' in navigator) {
    navigator.mediaSession.metadata = new MediaMetadata({
      title: "{{ radio.description | escape }}",
      artist: "{{ radio.title | escape }}",
      artwork: [
        {
          src: '{{ radio.logo.path | thumbnail: 192 }}',
          sizes: '192x192',
          type: 'image/{{ radio.logo.path | split: '.' | last }}'
        },
      ],
    })

    navigator.mediaSession.setActionHandler('play', () => transmission.play())
    navigator.mediaSession.setActionHandler('pause', () => transmission.pause())
  }

  // Volver a reproducir cuando se corte
  // TODO: Agregar los tracks
  transmission.addEventListener('ended', event => streaming(transmission))

  document.querySelectorAll('.share').forEach(share => {
    share.addEventListener('click', event => {
      if (!Navigator.share) return;

      event.preventDefault();
      event.stopPropagation();

      const title = document.querySelector('title').text;

      try {
        const text = document.querySelector('meta[property="og:description"]').content;
      } catch {
        const text = '';
      }

      try {
        const url = document.querySelector('link[rel=canonical]').href;
      } catch {
        const url = document.location.href;
      }

      const data = { title: title, text: text, url: url };

      if (Navigator.canShare(data)) Navigator.share(data).then();
    });
  });

  document.querySelectorAll("a[href^='http://'],a[href^='https://'],a[href^='//']").forEach(a => {
    a.rel = "noopener";
    a.target = "_blank";
  });
});
